<?php echo '<?xml version="1.0" encoding="utf-8"?>' ."\n" ?>
<?php mb_http_output('utf-8') ?>
<!--
## (c)2003-2007 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
##  $Id: weather.php,v 1.2 2007/08/09 02:26:41 nishi Exp $
-->

<vxml version="2.0" xml:lang="ja">

<?php
if(isset($_REQUEST['region']) && $_REQUEST['region'] != '') {
   $region = $_REQUEST['region'];
   mb_convert_variables("UTF-8", mb_detect_encoding($region), $region);
?>
<form id="answer">
  <block>
    <log>地域：<?php echo $region ?>，今日：晴れ，明日：曇り</log>
    <prompt>
      天気予報です。
      <?php echo $region ?>の、
      今日の天気は晴れです。
      明日は曇りです。
      <break/>
    </prompt>
    <goto next="#ask"/>
  </block>
</form>
<?php } ?>

<form id="ask">
  <field name="region">
   <prompt timeout="20s"> 
    天気を聞きたい地域を、東京、横浜、京都から選んでください。
   </prompt>
   <grammar version="1.0" root="#region_rule">
    <rule id="region_rule">
     <one-of>
      <item> <token sym="まいくてすと">マイクテスト</token> </item>
      <item> <token sym="とうきょう" slot="region">東京</token> </item>
      <item> <token sym="よこはま" slot="region">横浜</token> </item>
      <item> <token sym="きょうと" slot="region">京都</token> </item>
     </one-of>
    </rule>
   </grammar>
  </field>
  <block>
    <submit next="<?php echo basename(__FILE__) ?>"/> 
  </block>
</form>


</vxml> 
